@@ -55,6 +55,14 @@ typedef struct CCFBBrush_Struct {
     cairo_pattern_t *pattern;
 } CCFBBrush;
 
+extern const char *CCFBSymbolId;
+typedef struct CCFBSymbol_Struct {
+    const char *id;
+    cairo_path_t *path;
+    grdelBool filled;
+    char name[256];
+} CCFBSymbol;
+
 extern const char *CCFBFontId;
 typedef struct CCFBFont_Struct {
     const char *id;
@@ -167,14 +175,14 @@ grdelBool cairoCFerBind_replaceBrushColor(CFerBind *self,
                                           grdelType brush, grdelType color);
 grdelBool cairoCFerBind_deleteBrush(CFerBind *self, grdelType brush);
 grdelType cairoCFerBind_createSymbol(CFerBind *self, const char *symbolname, int namelen, 
-                                     const float ptsx[], const float ptsy[], int numpts);
+                        const float ptsx[], const float ptsy[], int numpts, grdelBool fill);
 grdelBool cairoCFerBind_deleteSymbol(CFerBind *self, grdelType symbol);
 grdelBool cairoCFerBind_setWidthFactor(CFerBind *self, double widthfactor);
 grdelBool cairoCFerBind_drawMultiline(CFerBind *self, double ptsx[], double ptsy[],
                                       int numpts, grdelType pen);
 grdelBool cairoCFerBind_drawPoints(CFerBind *self, double ptsx[], double ptsy[],
                                    int numpts, grdelType symbol, grdelType color,
-                                   double symsize);
+                                   double symsize, grdelType highlight);
 grdelBool cairoCFerBind_drawPolygon(CFerBind *self, double ptsx[], double ptsy[],
                                     int numpts, grdelType brush, grdelType pen);
 grdelBool cairoCFerBind_drawRectangle(CFerBind *self, double left, double bottom,
