@@ -1,6 +1,6 @@
 /* Make sure Python.h is included first */
 #include <Python.h>
-#include <stdlib.h>
+#include "ferret.h"
 #include "EF_Util.h"
 
 void FORTRAN(ef_get_mr_list)(int mr_list[EF_MAX_ARGS])
