@@ -38,13 +38,7 @@ class PyFerretBindings(AbstractPyFerretBindings):
         '''
         super(PyFerretBindings, self).__init__()
         self.__window = None
-        # short wait time in seconds for error responses 
-        # to high level (not drawing) commands
-        self.__shortwait = 0.01
-        # long wait time in seconds for error responses
-        # to major operations; eg, save
-        self.__longwait = 1.0
-
+ 
     def createPipedViewerWindow(self, viewertype, title, visible, noalpha):
         '''
         Creates a PipedViewer of viewertype as the window of this
@@ -72,36 +66,8 @@ class PyFerretBindings(AbstractPyFerretBindings):
             self.__window.submitCommand( {"action":"show"} )
         if noalpha:
             self.__window.submitCommand( {"action":"noalpha"} )
-        self.checkForErrorResponse(self.__shortwait)
         return True
 
-    def checkForErrorResponse(self, timeout=0.0):
-        '''
-        Checks the response pipe for a message that will be interpreted
-        as an error message.  If a response is found, a RuntimeError will
-        be raised with the string of the full response.
-
-        If timeout is zero (the default) the method does not wait if there
-        is no response waiting; otherwise the method waits the given number
-        of seconds for a response to arrive.  An IllegalArgumentException
-        if raised if timeout is None, as error responses should not be an
-        expected result (thus an indefinite wait makes no sense).
-        '''
-        if timeout is None:
-            raise IllegalArgumentException("timeout to checkForErrorResponse is None")
-        fullresponse = None
-        # Only wait (if timeout not zero) on the first check for a response
-        response = self.__window.checkForResponse(timeout)
-        while response:
-            if fullresponse:
-                fullresponse += '\n'
-                fullresponse += str(response)
-            else:
-                fullresponse = str(response)
-            # Any further messages associated with this error should be immediate
-            response = self.__window.checkForResponse()
-        if fullresponse:
-            raise RuntimeError(fullresponse)
 
     # The remaining methods are common implementations of the required binding methods
 
@@ -112,7 +78,7 @@ class PyFerretBindings(AbstractPyFerretBindings):
         Returns True.
         '''
         try:
-            closingremarks = self.__window.exitViewer()
+            closingremarks = self.__window.shutdownViewer()
         finally:
             self.__window = None
         return True
@@ -308,33 +274,37 @@ class PyFerretBindings(AbstractPyFerretBindings):
            screenwidth: width of the screen (display) in pixels (dots)
            screenheight: height of the screen (display) in pixels (dots)
         '''
-        cmnd = { "action":"screenInfo" }
-        self.__window.submitCommand(cmnd)
-        response = None
+        self.__window.blockErrMonitor()
         try:
-            # Wait indefinitely for a response
-            # Make sure it is a valid response
-            response = self.__window.checkForResponse(None)
-            if (type(response) != tuple) or (len(response) != 4):
-                raise ValueError
-            dpix = float(response[0])
-            dpiy = float(response[1])
-            screenwidth = int(response[2])
-            screenheight = int(response[3])
-            if (dpix <= 0.0) or (dpiy <= 0.0) or \
-               (screenwidth <= 0) or (screenheight <= 0):
-                raise ValueError
-        except Exception:
-            if not response:
-                # error raised before a response obtained
-                raise
-            fullresponse = str(response)
-            response = self.__window.checkForResponse()
-            while response:
-                fullresponse += '\n'
-                fullresponse += response
+            cmnd = { "action":"screenInfo" }
+            self.__window.submitCommand(cmnd)
+            response = None
+            try:
+                # Wait indefinitely for a response
+                # Make sure it is a valid response
+                response = self.__window.checkForResponse(None)
+                if (type(response) != tuple) or (len(response) != 4):
+                    raise ValueError
+                dpix = float(response[0])
+                dpiy = float(response[1])
+                screenwidth = int(response[2])
+                screenheight = int(response[3])
+                if (dpix <= 0.0) or (dpiy <= 0.0) or \
+                   (screenwidth <= 0) or (screenheight <= 0):
+                    raise ValueError
+            except Exception:
+                if not response:
+                    # error raised before a response obtained
+                    raise
+                fullresponse = str(response)
                 response = self.__window.checkForResponse()
-            raise RuntimeError(fullresponse)
+                while response:
+                    fullresponse += '\n'
+                    fullresponse += response
+                    response = self.__window.checkForResponse()
+                raise RuntimeError(fullresponse)
+        finally:
+            self.__window.resumeErrMonitor()
         return (dpix, dpiy, screenwidth, screenheight)
 
     def showWindow(self, visible):
@@ -390,8 +360,6 @@ class PyFerretBindings(AbstractPyFerretBindings):
         cmnd["rastsize"] = { "width":xpixels, "height":ypixels }
         cmnd["annotations"] = annotations
         self.__window.submitCommand(cmnd)
-        # Wait awhile to see if there was any problems
-        self.checkForErrorResponse(self.__longwait)
 
     def createColor(self, redfrac, greenfrac, bluefrac, opaquefrac):
         '''
@@ -561,35 +529,76 @@ class PyFerretBindings(AbstractPyFerretBindings):
         '''
         del brush
 
-    def createSymbol(self, symbolname, ptsx=None, ptsy=None):
+    def createSymbol(self, name, pts=None, fill=False):
         '''
-        Returns a Symbol object.
+        Returns a Symbol object associated with the given name.
+
+        If pts is not given, the symbol name must already be known, 
+        either as a pre-defined symbol or from a previous call to 
+        this method.
+
+        Current pre-defined symbol names are ones involving circles:
+            'dot': very small filled circle
+            'dotex': very small filled circle and outer lines of an ex mark
+            'dotplus': very small filled circle and outer lines of a plus mark
+            'circle': unfilled circle
+            'circex': small unfilled circle and outer lines of an ex mark
+            'circplus': small unfilled circle and outer lines of a plus mark
+
+        If pts is given, the value is coordinates that define the symbol 
+        as multiline subpaths in a [-50,50] square.  The location of the 
+        point this symbol represents will be at the center of the square. 
+        An invalid coordinate (outside [-50,50]) will terminate the current 
+        subpath, and the next valid coordinate will start a new subpath. 
+        This definition will replace an existing symbol with the given name.
 
         Arguments:
-            symbolname: name of the symbol, either a well-known
-                  symbol name (e.g., '.') or a custom name for a 
-                  symbol created from the given vertices (e.g., 'FER001')
-            ptsx: vertices X-coordinates describing the symbol 
-                  as a multiline drawing on a [0,100] square; 
-                  not used if a well-known symbol name is given
-            ptsy: vertices Y-coordinates describing the symbol 
-                  as a multiline drawing on a [0,100] square; 
-                  not used if a well-known symbol name is given
-        Currently supported well-known symbol names are:
-            '.' (period): filled circle
-            'o' (lowercase oh): unfilled circle
-            '+': plus mark
-            'x' (lowercase ex): x mark
-            '*': asterisk
-            '^': unfilled triangle
-            "#": unfilled square
+            name: (string) name of the symbol
+            pts:  (sequence of pairs of floats) vertex coordinates
+            fill: (bool) color-fill symbol?
 
-        Raises an error if ptsx and ptsy are needed but are not
-        sequence types of the same size or if unable to create 
-        the Symbol object for any other reason.
+        Raises an error 
+            if name is not a string, 
+            if pts, if not None, is not a sequence of pairs of numbers, or 
+            if unable to create the Symbol object for any other reason.
         '''
-        # TODO: support custom symbols
-        return symbolname
+        # If no points, assume the symbol is already defined but do not waste 
+        # time validating this.  The symbol object is just the symbol name.
+        if not isinstance(name, str):
+            raise RuntimeException('symbol name is not a string')
+        if pts is None:
+            return name
+        # Send the symbol definition to the viewer engine
+        self.__window.blockErrMonitor()
+        try:
+            cmnd = { 'action': 'createSymbol', 
+                     'name': name, 
+                     'pts': pts,
+                     'fill': fill }
+            self.__window.submitCommand(cmnd)
+            response = None
+            try:
+                # Wait indefinitely for a response.
+                # The valid response is the name of the symbol.
+                response = self.__window.checkForResponse(None)
+                if response != name:
+                    raise ValueError
+            except Exception:
+                if not response:
+                    # error raised before a response obtained
+                    raise
+                fullresponse = str(response)
+                response = self.__window.checkForResponse()
+                while response:
+                    fullresponse += '\n'
+                    fullresponse += response
+                    response = self.__window.checkForResponse()
+                raise RuntimeError(fullresponse)
+        finally:
+            self.__window.resumeErrMonitor()
+        # Since this symbol is now defined in the viewer engine,
+        # all we need is the name of this new symbol.
+        return name
 
     def deleteSymbol(self, symbol):
         '''
@@ -598,6 +607,7 @@ class PyFerretBindings(AbstractPyFerretBindings):
         Arguments:
             symbol: Symbol to be deleted
         '''
+        # TODO: delete the definition in the viewer engine
         del symbol
 
     def setWidthFactor(self, widthfactor):
@@ -635,7 +645,7 @@ class PyFerretBindings(AbstractPyFerretBindings):
                  "pen":pen }
         self.__window.submitCommand(cmnd)
 
-    def drawPoints(self, ptsx, ptsy, symbol, color, ptsize):
+    def drawPoints(self, ptsx, ptsy, symbol, color, ptsize, highlight):
         '''
         Draws discrete points.
 
@@ -643,8 +653,9 @@ class PyFerretBindings(AbstractPyFerretBindings):
             ptsx: X-coordinates of the points
             ptsy: Y-coordinates of the points
             symbol: the Symbol to use to draw a point
-            color: color of the Symbol (default color if None or empty)
+            color: color of the Symbol (default color if None)
             ptsize: size of the symbol (scales with view size)
+            highlight: color to outline the symbol; not outlined if None
 
         Coordinates are measured from the upper left corner
         in "device units" (pixels at the current window DPI).
@@ -661,6 +672,8 @@ class PyFerretBindings(AbstractPyFerretBindings):
         cmnd["points"] = points
         cmnd["symbol"] = symbol
         cmnd["size"] = ptsize
+        if highlight:
+            cmnd["highlight"] = highlight
         self.__window.submitCommand(cmnd)
 
     def drawPolygon(self, ptsx, ptsy, brush, pen):
@@ -728,32 +741,36 @@ class PyFerretBindings(AbstractPyFerretBindings):
         Returns: (width, height) of the text in "device units" 
               (pixels at the current window DPI) 
         '''
-        cmnd = { "action":"textSize", "text":text }
-        if font:
-            cmnd["font"] = font
-        self.__window.submitCommand(cmnd)
-        response = None
+        self.__window.blockErrMonitor()
         try:
-            # Wait indefinitely for a response
-            # Make sure it is a valid response
-            response = self.__window.checkForResponse(None)
-            if (type(response) != tuple) or (len(response) != 2):
-                raise ValueError
-            width = float(response[0])
-            height = float(response[1])
-            if (width <= 0.0) or (height <= 0.0):
-                raise ValueError
-        except Exception:
-            if not response:
-                # error raised before a response obtained
-                raise
-            fullresponse = str(response)
-            response = self.__window.checkForResponse()
-            while response:
-                fullresponse += '\n'
-                fullresponse += response
+            cmnd = { "action":"textSize", "text":text }
+            if font:
+                cmnd["font"] = font
+            self.__window.submitCommand(cmnd)
+            response = None
+            try:
+                # Wait indefinitely for a response
+                # Make sure it is a valid response
+                response = self.__window.checkForResponse(None)
+                if (type(response) != tuple) or (len(response) != 2):
+                    raise ValueError
+                width = float(response[0])
+                height = float(response[1])
+                if (width <= 0.0) or (height <= 0.0):
+                    raise ValueError
+            except Exception:
+                if not response:
+                    # error raised before a response obtained
+                    raise
+                fullresponse = str(response)
                 response = self.__window.checkForResponse()
-            raise RuntimeError(fullresponse)
+                while response:
+                    fullresponse += '\n'
+                    fullresponse += response
+                    response = self.__window.checkForResponse()
+                raise RuntimeError(fullresponse)
+        finally:
+            self.__window.resumeErrMonitor()
         return (width, height)
 
     def drawText(self, text, startx, starty, font, color, rotate):
@@ -881,8 +898,6 @@ class PImagerPQPyFerretBindings(PyFerretBindings):
                      "startindex":k*blocksize,
                      "blockdata":blkdata }
             self.__window.submitCommand(cmnd)
-        # wait briefly at the end for any error messages
-        self.checkForErrorResponse(self.__shortwait)
 
 
 #
@@ -921,7 +936,7 @@ def _test_pyferretbindings():
                 )
 
     # Initiate pyferret, but stay in python
-    pyferret.init(enterferret=False)
+    pyferret.init(arglist=['-nojnl'], enterferret=False)
     for viewertype in ( "PipedViewerPQ", ):
         print("Testing bindings for %s" % viewertype)
         # Create a viewer window
@@ -973,31 +988,43 @@ def _test_pyferretbindings():
         # Draw magenta points using various symbols
         ptsy = (50, 150, 250, 350, 450)
         ptsx = (100, 100, 100, 100, 100)
-        mysymbol = bindinst.createSymbol(".")
+        mysymbol = bindinst.createSymbol("dot")
         bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
         bindinst.deleteSymbol(mysymbol)
         ptsx = (150, 150, 150, 150, 150)
-        mysymbol = bindinst.createSymbol("o")
+        mysymbol = bindinst.createSymbol("circle")
         bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
         bindinst.deleteSymbol(mysymbol)
         ptsx = (200, 200, 200, 200, 200)
-        mysymbol = bindinst.createSymbol("+")
+        mysymbol = bindinst.createSymbol("dotplus")
         bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
         bindinst.deleteSymbol(mysymbol)
         ptsx = (250, 250, 250, 250, 250)
-        mysymbol = bindinst.createSymbol("x")
+        mysymbol = bindinst.createSymbol("circplus")
         bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
         bindinst.deleteSymbol(mysymbol)
         ptsx = (300, 300, 300, 300, 300)
-        mysymbol = bindinst.createSymbol("*")
+        mysymbol = bindinst.createSymbol("dotex")
         bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
         bindinst.deleteSymbol(mysymbol)
         ptsx = (350, 350, 350, 350, 350)
-        mysymbol = bindinst.createSymbol("^")
+        mysymbol = bindinst.createSymbol("circex")
         bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
         bindinst.deleteSymbol(mysymbol)
         ptsx = (400, 400, 400, 400, 400)
-        mysymbol = bindinst.createSymbol("#")
+        mysymbol = bindinst.createSymbol(name="filledtriangle",
+                            pts=( (-40.0, -30.0), (0.0, 39.282), (40.0, -30.0), (-40.0, -30.0), ),
+                            fill=True)
+        bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
+        bindinst.deleteSymbol(mysymbol)
+        ptsx = (450, 450, 450, 450, 450)
+        mysymbol = bindinst.createSymbol("bararrow", 
+                            ( (-50,50), (-10,10),
+                              (-999, -999),
+                              (50,0), (50,50), (0,50),
+                              (-999, -999),
+                              (0,-10), (20,-30), (10,-30), (10,-50), (-10,-50), (-10,-30), (-20,-30), (0,-10), ),
+                            False)
         bindinst.drawPoints(ptsx, ptsy, mysymbol, mycolors[7], 20)
         bindinst.deleteSymbol(mysymbol)
         # Draw a white dash line between some of the points
